@@ -3,7 +3,7 @@ use Mojo::Base 'Mojolicious::Controller', -signatures;
 
 our $DEV_MODE = ($ENV{MOJO_MODE} || '' =~ /dev/);
 
-has not_found_id   => 4;
+has not_found_id => sub { $_[0]->stranici->not_found_id };
 has not_found_code => 404;
 
 has description => 'Slovo is a simple extensible CMS.';
